# Pystagram
Instagram APIs Client for Python

Badges: Pypi, instagram, python version, license, code style, tests passing, coverage, documentation, last release

(Description, logo)
graph api

basic display api

readthedocs

## Features
- Basic features

## Installation
**Pystagram** can be installed from PyPI or from source.

### PyPI
```bash
pip install pystagram
```

### Source
```bash
git clone https://github.com/MatthieuThib/pystagram.git
cd pystagram
pip install .
```
## Table of Contents

### Graph API

### Basic Display API

## Usage

Publish media

Fetch media

Hashtag Search


## ?

cursor paginated endpoints

Some endpoints can return a lot of data, hence, they are
```
MAX_PAGES = 10
```


## TO DO
- Docker image








